| Title: | Learning Modules for Reliability Analysis |
|---|---|
| Description: | Learning modules for reliability analysis including modules for Reliability, Availability, and Maintainability (RAM) Analysis, Life Data Analysis, Reliability Testing, Repairable Systems Analysis, and Reliability Block Diagrams. |
| Authors: | Paul Govan [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-1821-8492>) |
| Maintainer: | Paul Govan <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 0.5 |
| Built: | 2026-05-30 02:36:25 UTC |
| Source: | https://github.com/paulgovan/relialearnr |
Availability is the proportion of time a system is in a functioning condition. This function computes availability given unavailable times and total times.
avail(unavailTime, totalTime)avail(unavailTime, totalTime)
unavailTime |
Numeric scalar or numeric vector of unavailable times. |
totalTime |
Numeric scalar or numeric vector of total times (same units as unavailTime). |
Numeric scalar: availability for the period (between 0 and 1).
avail(100, 1000) avail(c(5,10), c(500,600))avail(100, 1000) avail(c(5,10), c(500,600))
Failure rate is the frequency with which an engineered system or component fails, expressed in failures per unit of time. This function computes failure rate given failure counts and total operating times.
fr(failures, totalTime)fr(failures, totalTime)
failures |
Numeric scalar or numeric vector of failure counts (non-negative). |
totalTime |
Numeric scalar or numeric vector of total operating times. |
Numeric scalar: failures per unit time (failures / totalTime).
fr(75, 5000) fr(c(10,5), c(1000,2000))fr(75, 5000) fr(c(10,5), c(1000,2000))
This function launches an interactive tutorial for life data analysis.
lda()lda()
This function does not return a value.
https://paulgovan.github.io/ReliaLearnR/
if (interactive()) { lda() }if (interactive()) { lda() }
MTBF = total operating time / number of failures. The MTBF is the expected time between consecutive failures. It is commonly used for repairable items. The behavior is the same as mttf here; keep separate name for semantic clarity.
mtbf(failures, totalTime)mtbf(failures, totalTime)
failures |
Numeric scalar or numeric vector of failure counts (non-negative). |
totalTime |
Numeric scalar or numeric vector of total operating times. |
Numeric scalar: MTBF. If number of failures is zero, returns Inf (with a warning).
mtbf(5, 1000) mtbf(c(2,3), c(500,500))mtbf(5, 1000) mtbf(c(2,3), c(500,500))
For non-repairable items MTTF = total operating time / number of failures. The MTTF is the expected time to the first failure. It is commonly used for non-repairable items. The behavior implemented is the same as mtbf here; keep separate name for semantic clarity.
mttf(failures, totalTime)mttf(failures, totalTime)
failures |
Numeric scalar or numeric vector of failure counts (non-negative). |
totalTime |
Numeric scalar or numeric vector of total operating times. |
Numeric scalar: MTTF. If number of failures is zero, returns Inf (with a warning).
mttf(5, 1000) mttf(c(2,3), c(500,500))mttf(5, 1000) mttf(c(2,3), c(500,500))
This function launches an interactive tutorial on Reliability, Availability, and Maintainability (RAM) analysis.
ram()ram()
This function does not return a value.
https://paulgovan.github.io/ReliaLearnR/
if (interactive()) { ram() }if (interactive()) { ram() }
This function launches an interactive tutorial on Reliability Block Diagrams and system reliability, covering series, parallel, mixed, and k-out-of-n configurations as well as an introduction to Fault Tree Analysis.
rbd()rbd()
This function does not return a value.
https://paulgovan.github.io/ReliaLearnR/
if (interactive()) { rbd() }if (interactive()) { rbd() }
Reliability is the probability that an item will perform its intended function without failure over a specified period under stated conditions. This function computes reliability given outage times and total times.
rel(outageTime, totalTime)rel(outageTime, totalTime)
outageTime |
Numeric scalar or numeric vector of forced outage times. |
totalTime |
Numeric scalar or numeric vector of total times (same units as outageTime). |
Numeric scalar: reliability for the period (between 0 and 1).
rel(100, 1000) rel(c(10,20), c(500, 600))rel(100, 1000) rel(c(10,20), c(500, 600))
This function launches an interactive tutorial on Repairable Systems Analysis.
rs()rs()
This function does not return a value.
https://paulgovan.github.io/ReliaLearnR/
if (interactive()) { rs() }if (interactive()) { rs() }
This function launches the Reliability Testing tutorial
rt()rt()
This function does not return a value.
https://paulgovan.github.io/ReliaLearnR/
if (interactive()) { rt() }if (interactive()) { rt() }